/*
 * Anthony VH - November 2013
 * Receiver for the wireless quiz buttons.
 *
 * Using nRF24L01 library for RF interface.
 * See: https://github.com/aaronds/arduino-nrf24l01
 */

#include <SPI.h>
#include <Mirf.h>
#include <nRF24L01.h>
#include <MirfHardwareSpiDriver.h>

// Buffer to store data.
byte data[sizeof(byte)];

void setup()
{
  // Give bootloader some time to run.
  delay(1500);

  // Setup pins / SPI.
  Mirf.cePin = 9;
  Mirf.csnPin = 10;

  Mirf.spi = &MirfHardwareSpi;
  Mirf.init();

  // Configure receiving address.
  Mirf.setRADDR((byte *) "receiver");

  // Set the payload length to sizeof(byte)
  Mirf.payload = sizeof(byte);

  // we use channel 90 as it is outside of WLAN bands
  // or channels used by wireless surveillance cameras
  Mirf.channel = 90;

  Mirf.config();

  Serial.begin(115200);
  //Serial.println("[Receiver] Started");
}

void loop()
{
  /*
   * If a packet has been received.
   *
   * isSending also restores listening mode when it
   * transitions from true to false.
   */

  if(!Mirf.isSending() && Mirf.dataReady())
  {
    // Load the packet into the buffer.
    Mirf.getData(data);

    // Output result
    //Serial.print("[Receiver] Pushed: Button ");
    //Serial.println(data[0]);

    // Press enter
    //Keyboard.write('0' + data[0] + 1);
    //Keyboard.write(KEY_RETURN);

    char receivedID = '0' + data[0] + 1;
    Serial.write(receivedID);
    Serial.write('\r');
    Serial.write('\n');
  }
}
